==> vod-cloud-model-1.0.0-sources.jar: com/valor/vod/cloud/model/database/ddo/VendorCloudPkgDdo.java <==
package com.valor.vod.cloud.model.database.ddo;


import com.valor.vod.common.database.model.AbstractLMI;

import javax.persistence.*;

/**
 * @ClassName: VendorCloudDdo
 * @Auther: admin
 * @Date: 1/15/2019
 * @Version 1.0
 * @Description:
 */

@Entity
@Table(
    name = "mfc_vendor_cloud_pkg",
    indexes = {@Index(
        name = "index_vendor_cloud_pkg",
        columnList = "vendor_id"
    )}

)
public class VendorCloudPkgDdo extends AbstractLMI {

    private static final long serialVersionUID = -722518920059221622L;

    @Id
    @Column(
        name = "vendor_id"
    )
    private long vendorId;

    @Id
    @Column(
        name = "pkg_id"
    )
    private long pkgId;


    @Column(
        name = "status"
    )
    private int status; //0-disable 1-active


//    @Column(
//        name = "props"
//    )
//    private int props; //0-不需要加公共网盘 1-需要加公共网盘

    @Column(
        name = "remark"
    )
    private String remark;


    public long getVendorId() {
        return vendorId;
    }

    public void setVendorId(long vendorId) {
        this.vendorId = vendorId;
    }

    public int getStatus() {
        return status;
    }

    public void setStatus(int status) {
        this.status = status;
    }

//    public int getProps() {
//        return props;
//    }
//
//    public void setProps(int props) {
//        this.props = props;
//    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public long getPkgId() {
        return pkgId;
    }

    public void setPkgId(long pkgId) {
        this.pkgId = pkgId;
    }
}

==> vod-cloud-model-3.1.4-sources.jar: com/valor/vod/cloud/model/database/ddo/VendorCloudPkgDdo.java <==
package com.valor.vod.cloud.model.database.ddo;


import com.valor.vod.common.database.model.AbstractLMI;

import javax.persistence.*;

/**
 * @ClassName: VendorCloudDdo
 * @Auther: admin
 * @Date: 1/15/2019
 * @Version 1.0
 * @Description:
 */

@Entity
@Table(
    name = "mfc_vendor_cloud_pkg",
    indexes = {@Index(
        name = "index_vendor_cloud_pkg",
        columnList = "vendor_id"
    )}

)
public class VendorCloudPkgDdo extends TenantAbstractLMI {

    private static final long serialVersionUID = -722518920059221622L;

    @Id
    @Column(
        name = "vendor_id"
    )
    private long vendorId;

    @Id
    @Column(
        name = "pkg_id"
    )
    private long pkgId;


    @Column(
        name = "status"
    )
    private int status; //0-disable 1-active


//    @Column(
//        name = "props"
//    )
//    private int props; //0-不需要加公共网盘 1-需要加公共网盘

    @Column(
        name = "remark"
    )
    private String remark;


    public long getVendorId() {
        return vendorId;
    }

    public void setVendorId(long vendorId) {
        this.vendorId = vendorId;
    }

    public int getStatus() {
        return status;
    }

    public void setStatus(int status) {
        this.status = status;
    }

//    public int getProps() {
//        return props;
//    }
//
//    public void setProps(int props) {
//        this.props = props;
//    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public long getPkgId() {
        return pkgId;
    }

    public void setPkgId(long pkgId) {
        this.pkgId = pkgId;
    }
}
